package com.bs.ct.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bs.common.annotation.Log;
import com.bs.common.core.controller.BaseController;
import com.bs.common.core.domain.AjaxResult;
import com.bs.common.core.page.TableDataInfo;
import com.bs.common.enums.BusinessType;
import com.bs.common.utils.poi.ExcelUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import cn.hutool.core.lang.Validator;
import com.bs.ct.domain.CtTaskTemplateTag;
import com.bs.ct.service.ICtTaskTemplateTagService;
import javax.annotation.Resource;

/**
 * 任务模板标签Controller
 *
 * @author bs
 * @date 2025-02-22
 */
@Api(tags = "任务模板标签")
@RestController
@RequestMapping("/task/template/tag")
public class CtTaskTemplateTagController extends BaseController {
    @Resource
    private ICtTaskTemplateTagService ctTaskTemplateTagService;

    /**
     * 分页查询任务模板标签列表
     */
    @ApiOperation("分页查询任务模板标签列表")
    @GetMapping("/pageList")
    public TableDataInfo pageList(CtTaskTemplateTag ctTaskTemplateTag) {
        startPage();
        LambdaQueryWrapper<CtTaskTemplateTag> queryWrapper = new LambdaQueryWrapper();
        condition(queryWrapper,ctTaskTemplateTag);
        List<CtTaskTemplateTag> list = ctTaskTemplateTagService.list(queryWrapper);
        return getDataTable(list);
    }

    /**
     * 查询任务模板标签列表
     */
    @ApiOperation("查询任务模板标签列表")
    @GetMapping("/list")
    public AjaxResult list(CtTaskTemplateTag ctTaskTemplateTag) {
        LambdaQueryWrapper<CtTaskTemplateTag> queryWrapper = new LambdaQueryWrapper();
        condition(queryWrapper,ctTaskTemplateTag);
        List<CtTaskTemplateTag> list = ctTaskTemplateTagService.list(queryWrapper);
        return success(list);
    }

    /**
     * 导出任务模板标签列表
     */
    @ApiOperation("导出任务模板标签列表")
    @Log(title = "任务模板标签导出", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CtTaskTemplateTag ctTaskTemplateTag) {
        LambdaQueryWrapper<CtTaskTemplateTag> queryWrapper = new LambdaQueryWrapper();
        condition(queryWrapper,ctTaskTemplateTag);
        List<CtTaskTemplateTag> list = ctTaskTemplateTagService.list(queryWrapper);
        ExcelUtil<CtTaskTemplateTag> util = new ExcelUtil<CtTaskTemplateTag>(CtTaskTemplateTag. class);
        util.exportExcel(response, list, "任务模板标签数据");
    }

    /**
     * 获取任务模板标签详细信息
     */
    @ApiOperation("获取任务模板标签详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(ctTaskTemplateTagService.getById(id));
    }

    /**
     * 新增任务模板标签
     */
    @ApiOperation("新增任务模板标签")
    @Log(title = "任务模板标签新增", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CtTaskTemplateTag ctTaskTemplateTag) {
        return toAjax(ctTaskTemplateTagService.save(ctTaskTemplateTag));
    }

    /**
     * 修改任务模板标签
     */
    @ApiOperation("修改任务模板标签")
    @Log(title = "任务模板标签修改", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CtTaskTemplateTag ctTaskTemplateTag) {
        return toAjax(ctTaskTemplateTagService.updateById(ctTaskTemplateTag));
    }

    /**
     * 删除任务模板标签
     */
    @ApiOperation("删除任务模板标签")
    @Log(title = "任务模板标签删除", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids) {
        return toAjax(ctTaskTemplateTagService.removeBatchByIds(ids));
    }

    /**
      * 条件设置
      */
    private void condition (LambdaQueryWrapper<CtTaskTemplateTag> queryWrapper,CtTaskTemplateTag ctTaskTemplateTag){


        //id
        if(Validator.isNotEmpty(ctTaskTemplateTag.getId())){
            queryWrapper.eq(CtTaskTemplateTag::getId,ctTaskTemplateTag.getId());
        }

        //任务模板id
        if(Validator.isNotEmpty(ctTaskTemplateTag.getTemplateId())){
            queryWrapper.eq(CtTaskTemplateTag::getTemplateId,ctTaskTemplateTag.getTemplateId());
        }

        //标签名称
        if(Validator.isNotEmpty(ctTaskTemplateTag.getTagName())){
            queryWrapper.eq(CtTaskTemplateTag::getTagName,ctTaskTemplateTag.getTagName());
        }

        //标签说明
        if(Validator.isNotEmpty(ctTaskTemplateTag.getTagDesc())){
            queryWrapper.eq(CtTaskTemplateTag::getTagDesc,ctTaskTemplateTag.getTagDesc());
        }

        //是否需要拍照
        if(Validator.isNotEmpty(ctTaskTemplateTag.getIsPhoto())){
            queryWrapper.eq(CtTaskTemplateTag::getIsPhoto,ctTaskTemplateTag.getIsPhoto());
        }

        //拍照数量要求
        if(Validator.isNotEmpty(ctTaskTemplateTag.getPhotoNum())){
            queryWrapper.eq(CtTaskTemplateTag::getPhotoNum,ctTaskTemplateTag.getPhotoNum());
        }

        //照片存放目录
        if(Validator.isNotEmpty(ctTaskTemplateTag.getSaveDir())){
            queryWrapper.eq(CtTaskTemplateTag::getSaveDir,ctTaskTemplateTag.getSaveDir());
        }

        //附件id
        if(Validator.isNotEmpty(ctTaskTemplateTag.getFileId())){
            queryWrapper.eq(CtTaskTemplateTag::getFileId,ctTaskTemplateTag.getFileId());
        }

        //备注
        if(Validator.isNotEmpty(ctTaskTemplateTag.getRemarks())){
            queryWrapper.eq(CtTaskTemplateTag::getRemarks,ctTaskTemplateTag.getRemarks());
        }

        //删除标志（0代表存在 2代表删除）
        if(Validator.isNotEmpty(ctTaskTemplateTag.getDelFlag())){
            queryWrapper.eq(CtTaskTemplateTag::getDelFlag,ctTaskTemplateTag.getDelFlag());
        }

        //创建部门
        if(Validator.isNotEmpty(ctTaskTemplateTag.getCreateDept())){
            queryWrapper.eq(CtTaskTemplateTag::getCreateDept,ctTaskTemplateTag.getCreateDept());
        }

        //创建人
        if(Validator.isNotEmpty(ctTaskTemplateTag.getCreateBy())){
            queryWrapper.eq(CtTaskTemplateTag::getCreateBy,ctTaskTemplateTag.getCreateBy());
        }

        //创建时间
        if(Validator.isNotEmpty(ctTaskTemplateTag.getCreateTime())){
            queryWrapper.eq(CtTaskTemplateTag::getCreateTime,ctTaskTemplateTag.getCreateTime());
        }

        //修改人
        if(Validator.isNotEmpty(ctTaskTemplateTag.getUpdateBy())){
            queryWrapper.eq(CtTaskTemplateTag::getUpdateBy,ctTaskTemplateTag.getUpdateBy());
        }

        //修改时间
        if(Validator.isNotEmpty(ctTaskTemplateTag.getUpdateTime())){
            queryWrapper.eq(CtTaskTemplateTag::getUpdateTime,ctTaskTemplateTag.getUpdateTime());
        }

        //租户ID
        if(Validator.isNotEmpty(ctTaskTemplateTag.getTenantId())){
            queryWrapper.eq(CtTaskTemplateTag::getTenantId,ctTaskTemplateTag.getTenantId());
        }

        }

}
